package office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.commons.lang.time.DateFormatUtils;

import office.api.common.APIType;
import office.api.common.Action;

import office.api.schedule.Span;

public class ScheduleGetEventsByTarget implements Action {
	
	private List<String> userIDs = new ArrayList<String>();
	private List<String> groupIDs = new ArrayList<String>();
	private List<String> facilityIDs = new ArrayList<String>();
	
	private Span search_span = new Span();
	
	@Override
	public String getActionName() {
		return "ScheduleGetEventsByTarget";
	}

	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * ユーザーIDを追加します。
	 * 
	 * @param userid ユーザーID
	 */
	public void addUserID(String userid)
	{
		userIDs.add( userid );
	}
	
	/**
	 * グループIDを追加します。
	 * 
	 * @param groupid グループID
	 */
	public void addGroupID(String groupid)
	{
		groupIDs.add( groupid );
	}
	
	/**
	 * 施設IDを追加します。
	 * 
	 * @param facilityid 施設ID
	 */
	public void addFacilityID(String facilityid)
	{
		facilityIDs.add( facilityid );
	}
	
	/**
	 * 検索期間を設定します。
	 * 
	 * @param span 検索期間の開始日時と終了日時
	 */
	public void setSpan(Span span)
	{
		search_span = span;
	}

	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
    	String start = DateFormatUtils.ISO_DATETIME_FORMAT.format( search_span.getStart() );
    	String end   = DateFormatUtils.ISO_DATETIME_FORMAT.format( search_span.getEnd() );
    	
    	parameters.addAttribute("start",start,null);
    	parameters.addAttribute("end",end,null);

        for (String id : this.userIDs) {	//ユーザーIDをセット
            OMElement facility = omFactory.createOMElement("user", null);
            facility.addAttribute("id",id,null);
            parameters.addChild(facility);
        }

        for (String id : this.groupIDs) {	//グループIDをセット
            OMElement facility = omFactory.createOMElement("group", null);
            facility.addAttribute("id",id,null);
            parameters.addChild(facility);
        }

        
        for (String id : this.facilityIDs) {	//施設IDをセット
            OMElement facility = omFactory.createOMElement("facility", null);
            facility.addAttribute("id",id,null);
            parameters.addChild(facility);
        }
        
        return parameters;
	}

}
